.. cyeva documentation master file, created by
   sphinx-quickstart on Mon Jun  6 15:11:00 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: _static/logo.png

cyeva 是一个由彩云科技天气团队开发的用于对气象要素确定性预报准确率进行快速评测的 Python 开源工具库。

cyeva 将致力于让气象要素确定性预报准确率的自动化评估变得简单直接，将集成常用的确定性预报准确率评估指标且内部算法广泛使用了 NumPy 的向量运算实现，对于大数据量的计算也具有较高的计算效率。

使用指南
---------------

.. toctree::
   :maxdepth: 3

   content/installation
   content/usage
   content/indicator
   content/api-ref
   content/contributor-guide
   content/license
   content/citation
   content/changelog
   content/appendix
